"""Generated model names for requesty provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 86
"""

from __future__ import annotations

from typing import Literal


RequestyModels = Literal[
    "requesty:alibaba/qwen3-30b-a3b-instruct-2507",
    "requesty:alibaba/qwen3-coder-flash",
    "requesty:alibaba/qwen3-coder-plus",
    "requesty:alibaba/qwen3-max",
    "requesty:anthropic/claude-haiku-4-5",
    "requesty:anthropic/claude-opus-4-1",
    "requesty:anthropic/claude-opus-4-5",
    "requesty:anthropic/claude-sonnet-4-5",
    "requesty:azure/gpt-5.1",
    "requesty:azure/gpt-5.1@swedencentral",
    "requesty:bedrock/claude-haiku-4-5",
    "requesty:bedrock/claude-haiku-4-5@eu-central-1",
    "requesty:bedrock/claude-haiku-4-5@eu-north-1",
    "requesty:bedrock/claude-haiku-4-5@eu-west-1",
    "requesty:bedrock/claude-haiku-4-5@eu-west-3",
    "requesty:bedrock/claude-haiku-4-5@us-east-1",
    "requesty:bedrock/claude-haiku-4-5@us-east-2",
    "requesty:bedrock/claude-haiku-4-5@us-west-2",
    "requesty:bedrock/claude-opus-4-5",
    "requesty:deepinfra/Qwen/Qwen3-Coder-480B-A35B-Instruct",
    "requesty:deepinfra/deepseek-ai/DeepSeek-V3.1",
    "requesty:deepinfra/zai-org/GLM-4.5",
    "requesty:deepinfra/zai-org/GLM-4.5-Air",
    "requesty:groq/moonshotai/Kimi-K2-Instruct-0905",
    "requesty:groq/moonshotai/kimi-k2-instruct",
    "requesty:groq/openai/gpt-oss-120b",
    "requesty:groq/openai/gpt-oss-20b",
    "requesty:minimaxi/MiniMax-M2",
    "requesty:moonshot/kimi-k2-0711-preview",
    "requesty:moonshot/kimi-k2-0905-preview",
    "requesty:moonshot/kimi-k2-thinking",
    "requesty:moonshot/kimi-k2-thinking-turbo",
    "requesty:moonshot/kimi-k2-turbo-preview",
    "requesty:nebius/Qwen/Qwen3-Coder-480B-A35B-Instruct",
    "requesty:nebius/deepseek-ai/DeepSeek-V3-0324-fast",
    "requesty:nebius/moonshotai/Kimi-K2-Instruct",
    "requesty:nebius/zai-org/GLM-4.5",
    "requesty:novita/deepseek/deepseek-v3-0324",
    "requesty:novita/deepseek/deepseek-v3-turbo",
    "requesty:novita/deepseek/deepseek_v3",
    "requesty:novita/moonshotai/kimi-k2-instruct",
    "requesty:novita/zai-org/glm-4.5",
    "requesty:novita/zai-org/glm-4.6",
    "requesty:openai-responses/gpt-5",
    "requesty:openai-responses/gpt-5-codex",
    "requesty:openai-responses/gpt-5-mini",
    "requesty:openai-responses/gpt-5-nano",
    "requesty:openai-responses/gpt-5-pro",
    "requesty:openai-responses/gpt-5.1-codex",
    "requesty:openai-responses/o3-pro",
    "requesty:openai/gpt-5",
    "requesty:openai/gpt-5-chat",
    "requesty:openai/gpt-5-mini",
    "requesty:openai/gpt-5-mini:flex",
    "requesty:openai/gpt-5-mini:priority",
    "requesty:openai/gpt-5-nano",
    "requesty:openai/gpt-5-nano:flex",
    "requesty:openai/gpt-5.1",
    "requesty:openai/gpt-5.1-chat",
    "requesty:openai/gpt-5:flex",
    "requesty:openai/gpt-5:priority",
    "requesty:openai/o3-deep-research",
    "requesty:openai/o4-mini-deep-research",
    "requesty:parasail/parasail-deepseek-v3-0324",
    "requesty:parasail/parasail-glm-45",
    "requesty:parasail/parasail-kimi-k2-instruct",
    "requesty:parasail/parasail-qwen3-235b-a22b-instruct-2507",
    "requesty:together/deepseek-ai/DeepSeek-R1",
    "requesty:together/deepseek-ai/DeepSeek-V3",
    "requesty:vertex/claude-opus-4-5",
    "requesty:vertex/claude-opus-4-5@europe-west1",
    "requesty:vertex/claude-opus-4-5@us-east5",
    "requesty:vertex/gemini-2.5-flash-image-preview",
    "requesty:xai/grok-2-1212",
    "requesty:xai/grok-3",
    "requesty:xai/grok-3-mini",
    "requesty:xai/grok-3-mini:high",
    "requesty:xai/grok-3-mini:low",
    "requesty:xai/grok-4",
    "requesty:xai/grok-4-1-fast-non-reasoning",
    "requesty:xai/grok-4-1-fast-reasoning",
    "requesty:xai/grok-4-fast",
    "requesty:xai/grok-4-fast-non-reasoning",
    "requesty:xai/grok-code-fast-1",
    "requesty:zai/GLM-4.5",
    "requesty:zai/GLM-4.6",
]

__all__ = ["RequestyModels"]



"""Generated model names for github provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 82
"""

from __future__ import annotations

from typing import Literal


GithubModels = Literal[
    "github:AI21-Jamba-1.5-Large",
    "github:AI21-Jamba-1.5-Mini",
    "github:Aurora",
    "github:BioEmu",
    "github:Codestral-2501",
    "github:Cohere-command-r",
    "github:Cohere-command-r-08-2024",
    "github:Cohere-command-r-plus",
    "github:Cohere-command-r-plus-08-2024",
    "github:Cohere-embed-v3-english",
    "github:Cohere-embed-v3-multilingual",
    "github:DeepSeek-R1",
    "github:DeepSeek-R1-0528",
    "github:DeepSeek-V3",
    "github:DeepSeek-V3-0324",
    "github:DeepSeek-V3.1",
    "github:EvoDiff",
    "github:Flux-1.1-Pro",
    "github:Flux.1-Kontext-pro",
    "github:Llama-3.2-11B-Vision-Instruct",
    "github:Llama-3.2-90B-Vision-Instruct",
    "github:Llama-3.3-70B-Instruct",
    "github:Llama-4-Maverick-17B-128E-Instruct-FP8",
    "github:Llama-4-Scout-17B-16E",
    "github:Llama-4-Scout-17B-16E-Instruct",
    "github:MAI-DS-R1",
    "github:MatterGen",
    "github:Meta-Llama-3-70B-Instruct",
    "github:Meta-Llama-3-8B-Instruct",
    "github:Meta-Llama-3.1-405B-Instruct",
    "github:Meta-Llama-3.1-70B-Instruct",
    "github:Meta-Llama-3.1-8B-Instruct",
    "github:Ministral-3B",
    "github:Ministral-8B",
    "github:Mistral-Large-2411",
    "github:Mistral-Large-3",
    "github:Mistral-Nemo",
    "github:Mistral-large-2407",
    "github:Mistral-small",
    "github:Muse",
    "github:Phi-4-mini-flash-reasoning",
    "github:Phi-4-reasoning-plus",
    "github:codex-mini",
    "github:cohere-command-a",
    "github:computer-use-preview",
    "github:embed-v-4-0",
    "github:financial-reports-analysis-v2",
    "github:gpt-4.1",
    "github:gpt-4.1-mini",
    "github:gpt-4.1-nano",
    "github:gpt-4.5-preview",
    "github:gpt-4o",
    "github:gpt-4o-mini",
    "github:gpt-4o-mini-transcribe",
    "github:gpt-4o-mini-tts",
    "github:gpt-4o-transcribe",
    "github:gpt-4o-transcribe-diarize",
    "github:gpt-5",
    "github:gpt-5-chat",
    "github:gpt-5-codex",
    "github:gpt-5-mini",
    "github:gpt-5-nano",
    "github:gpt-5.1",
    "github:gpt-5.1-codex",
    "github:gpt-5.1-codex-max",
    "github:gpt-5.1-codex-mini",
    "github:gpt-image-1",
    "github:gpt-image-1-mini",
    "github:grok-3",
    "github:grok-3-mini",
    "github:jais-30b-chat",
    "github:mistral-document-ai-2505",
    "github:mistral-medium-2505",
    "github:mistral-ocr-2503",
    "github:mistral-small-2503",
    "github:model-router",
    "github:o3-deep-research",
    "github:o3-pro",
    "github:retrochimera",
    "github:sora",
    "github:sora-2",
    "github:supply-chain-trade-regulations-v2",
]

__all__ = ["GithubModels"]



"""Generated model names for xai provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 6
"""

from __future__ import annotations

from typing import Literal


XaiModels = Literal[
    "xai:grok-4-0709",
    "xai:grok-4-1-fast-non-reasoning",
    "xai:grok-4-1-fast-reasoning",
    "xai:grok-4-fast-non-reasoning",
    "xai:grok-4-fast-reasoning",
    "xai:grok-code-fast-1",
]

__all__ = ["XaiModels"]



"""Generated model names for openrouter provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 156
"""

from __future__ import annotations

from typing import Literal


OpenrouterModels = Literal[
    "openrouter:ai21/jamba-large-1.7",
    "openrouter:ai21/jamba-mini-1.7",
    "openrouter:alibaba/tongyi-deepresearch-30b-a3b",
    "openrouter:alibaba/tongyi-deepresearch-30b-a3b:free",
    "openrouter:allenai/olmo-3-32b-think:free",
    "openrouter:allenai/olmo-3-7b-instruct",
    "openrouter:allenai/olmo-3-7b-think",
    "openrouter:amazon/nova-2-lite-v1",
    "openrouter:amazon/nova-2-lite-v1:free",
    "openrouter:amazon/nova-premier-v1",
    "openrouter:anthropic/claude-haiku-4.5",
    "openrouter:anthropic/claude-opus-4.1",
    "openrouter:anthropic/claude-opus-4.5",
    "openrouter:anthropic/claude-sonnet-4.5",
    "openrouter:arcee-ai/trinity-mini",
    "openrouter:arcee-ai/trinity-mini:free",
    "openrouter:baidu/ernie-4.5-21b-a3b",
    "openrouter:baidu/ernie-4.5-21b-a3b-thinking",
    "openrouter:baidu/ernie-4.5-300b-a47b",
    "openrouter:baidu/ernie-4.5-vl-28b-a3b",
    "openrouter:baidu/ernie-4.5-vl-424b-a47b",
    "openrouter:bytedance/ui-tars-1.5-7b",
    "openrouter:cognitivecomputations/dolphin-mistral-24b-venice-edition:free",
    "openrouter:deepcogito/cogito-v2-preview-llama-109b-moe",
    "openrouter:deepcogito/cogito-v2-preview-llama-405b",
    "openrouter:deepcogito/cogito-v2-preview-llama-70b",
    "openrouter:deepcogito/cogito-v2.1-671b",
    "openrouter:deepseek/deepseek-chat-v3.1",
    "openrouter:deepseek/deepseek-r1-0528",
    "openrouter:deepseek/deepseek-r1-0528-qwen3-8b",
    "openrouter:deepseek/deepseek-v3.1-terminus",
    "openrouter:deepseek/deepseek-v3.1-terminus:exacto",
    "openrouter:deepseek/deepseek-v3.2",
    "openrouter:deepseek/deepseek-v3.2-exp",
    "openrouter:deepseek/deepseek-v3.2-speciale",
    "openrouter:essentialai/rnj-1-instruct",
    "openrouter:google/gemini-2.5-flash",
    "openrouter:google/gemini-2.5-flash-image",
    "openrouter:google/gemini-2.5-flash-image-preview",
    "openrouter:google/gemini-2.5-flash-lite",
    "openrouter:google/gemini-2.5-flash-lite-preview-09-2025",
    "openrouter:google/gemini-2.5-flash-preview-09-2025",
    "openrouter:google/gemini-2.5-pro",
    "openrouter:google/gemini-2.5-pro-preview",
    "openrouter:google/gemini-3-pro-image-preview",
    "openrouter:google/gemini-3-pro-preview",
    "openrouter:google/gemma-3n-e2b-it:free",
    "openrouter:ibm-granite/granite-4.0-h-micro",
    "openrouter:inception/mercury",
    "openrouter:kwaipilot/kat-coder-pro:free",
    "openrouter:liquid/lfm-2.2-6b",
    "openrouter:liquid/lfm2-8b-a1b",
    "openrouter:meituan/longcat-flash-chat",
    "openrouter:meituan/longcat-flash-chat:free",
    "openrouter:minimax/minimax-m1",
    "openrouter:minimax/minimax-m2",
    "openrouter:mistralai/codestral-2508",
    "openrouter:mistralai/devstral-medium",
    "openrouter:mistralai/devstral-small",
    "openrouter:mistralai/ministral-14b-2512",
    "openrouter:mistralai/ministral-3b-2512",
    "openrouter:mistralai/ministral-8b-2512",
    "openrouter:mistralai/mistral-large-2512",
    "openrouter:mistralai/mistral-medium-3.1",
    "openrouter:mistralai/mistral-small-3.2-24b-instruct",
    "openrouter:mistralai/voxtral-small-24b-2507",
    "openrouter:moonshotai/kimi-dev-72b",
    "openrouter:moonshotai/kimi-k2",
    "openrouter:moonshotai/kimi-k2-0905",
    "openrouter:moonshotai/kimi-k2-0905:exacto",
    "openrouter:moonshotai/kimi-k2-thinking",
    "openrouter:moonshotai/kimi-k2:free",
    "openrouter:moonshotai/kimi-linear-48b-a3b-instruct",
    "openrouter:morph/morph-v3-fast",
    "openrouter:morph/morph-v3-large",
    "openrouter:nousresearch/hermes-4-405b",
    "openrouter:nousresearch/hermes-4-70b",
    "openrouter:nvidia/llama-3.3-nemotron-super-49b-v1.5",
    "openrouter:nvidia/nemotron-nano-12b-v2-vl",
    "openrouter:nvidia/nemotron-nano-12b-v2-vl:free",
    "openrouter:nvidia/nemotron-nano-9b-v2",
    "openrouter:nvidia/nemotron-nano-9b-v2:free",
    "openrouter:openai/gpt-4o-audio-preview",
    "openrouter:openai/gpt-5",
    "openrouter:openai/gpt-5-chat",
    "openrouter:openai/gpt-5-codex",
    "openrouter:openai/gpt-5-image",
    "openrouter:openai/gpt-5-image-mini",
    "openrouter:openai/gpt-5-mini",
    "openrouter:openai/gpt-5-nano",
    "openrouter:openai/gpt-5-pro",
    "openrouter:openai/gpt-5.1",
    "openrouter:openai/gpt-5.1-chat",
    "openrouter:openai/gpt-5.1-codex",
    "openrouter:openai/gpt-5.1-codex-max",
    "openrouter:openai/gpt-5.1-codex-mini",
    "openrouter:openai/gpt-oss-120b",
    "openrouter:openai/gpt-oss-120b:exacto",
    "openrouter:openai/gpt-oss-120b:free",
    "openrouter:openai/gpt-oss-20b",
    "openrouter:openai/gpt-oss-20b:free",
    "openrouter:openai/gpt-oss-safeguard-20b",
    "openrouter:openai/o3-deep-research",
    "openrouter:openai/o3-pro",
    "openrouter:openai/o4-mini-deep-research",
    "openrouter:opengvlab/internvl3-78b",
    "openrouter:openrouter/bodybuilder",
    "openrouter:perplexity/sonar-pro-search",
    "openrouter:prime-intellect/intellect-3",
    "openrouter:qwen/qwen-plus-2025-07-28",
    "openrouter:qwen/qwen-plus-2025-07-28:thinking",
    "openrouter:qwen/qwen3-235b-a22b-2507",
    "openrouter:qwen/qwen3-235b-a22b-thinking-2507",
    "openrouter:qwen/qwen3-30b-a3b-instruct-2507",
    "openrouter:qwen/qwen3-30b-a3b-thinking-2507",
    "openrouter:qwen/qwen3-coder",
    "openrouter:qwen/qwen3-coder-30b-a3b-instruct",
    "openrouter:qwen/qwen3-coder-flash",
    "openrouter:qwen/qwen3-coder-plus",
    "openrouter:qwen/qwen3-coder:exacto",
    "openrouter:qwen/qwen3-coder:free",
    "openrouter:qwen/qwen3-max",
    "openrouter:qwen/qwen3-next-80b-a3b-instruct",
    "openrouter:qwen/qwen3-next-80b-a3b-thinking",
    "openrouter:qwen/qwen3-vl-235b-a22b-instruct",
    "openrouter:qwen/qwen3-vl-235b-a22b-thinking",
    "openrouter:qwen/qwen3-vl-30b-a3b-instruct",
    "openrouter:qwen/qwen3-vl-30b-a3b-thinking",
    "openrouter:qwen/qwen3-vl-8b-instruct",
    "openrouter:qwen/qwen3-vl-8b-thinking",
    "openrouter:relace/relace-apply-3",
    "openrouter:relace/relace-search",
    "openrouter:stepfun-ai/step3",
    "openrouter:switchpoint/router",
    "openrouter:tencent/hunyuan-a13b-instruct",
    "openrouter:thedrummer/anubis-70b-v1.1",
    "openrouter:thedrummer/cydonia-24b-v4.1",
    "openrouter:thudm/glm-4.1v-9b-thinking",
    "openrouter:tngtech/deepseek-r1t2-chimera",
    "openrouter:tngtech/deepseek-r1t2-chimera:free",
    "openrouter:tngtech/tng-r1t-chimera",
    "openrouter:tngtech/tng-r1t-chimera:free",
    "openrouter:x-ai/grok-3",
    "openrouter:x-ai/grok-3-mini",
    "openrouter:x-ai/grok-4",
    "openrouter:x-ai/grok-4-fast",
    "openrouter:x-ai/grok-4.1-fast",
    "openrouter:x-ai/grok-code-fast-1",
    "openrouter:z-ai/glm-4-32b",
    "openrouter:z-ai/glm-4.5",
    "openrouter:z-ai/glm-4.5-air",
    "openrouter:z-ai/glm-4.5-air:free",
    "openrouter:z-ai/glm-4.5v",
    "openrouter:z-ai/glm-4.6",
    "openrouter:z-ai/glm-4.6:exacto",
    "openrouter:z-ai/glm-4.6v",
]

__all__ = ["OpenrouterModels"]



"""Generated model names for copilot provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 17
"""

from __future__ import annotations

from typing import Literal


CopilotModels = Literal[
    "copilot:claude-haiku-4.5",
    "copilot:claude-opus-4.5",
    "copilot:claude-sonnet-4",
    "copilot:claude-sonnet-4.5",
    "copilot:gemini-2.5-pro",
    "copilot:gemini-3-pro-preview",
    "copilot:gpt-4.1",
    "copilot:gpt-4o",
    "copilot:gpt-5",
    "copilot:gpt-5-codex",
    "copilot:gpt-5-mini",
    "copilot:gpt-5.1",
    "copilot:gpt-5.1-codex",
    "copilot:gpt-5.1-codex-max",
    "copilot:gpt-5.1-codex-mini",
    "copilot:grok-code-fast-1",
    "copilot:oswe-vscode-prime",
]

__all__ = ["CopilotModels"]



"""Generated model names for openai provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 12
"""

from __future__ import annotations

from typing import Literal


OpenaiModels = Literal[
    "openai:gpt-5",
    "openai:gpt-5-chat-latest",
    "openai:gpt-5-codex",
    "openai:gpt-5-mini",
    "openai:gpt-5-nano",
    "openai:gpt-5-pro",
    "openai:gpt-5.1",
    "openai:gpt-5.1-chat-latest",
    "openai:gpt-5.1-codex",
    "openai:gpt-5.1-codex-max",
    "openai:gpt-5.1-codex-mini",
    "openai:o3-pro",
]

__all__ = ["OpenaiModels"]
